'use strict'

import c from 'classnames'
import PropTypes from 'prop-types'
import React from 'react'
import { eventHandlersFor, htmlAttributesFor } from 'the-component-util'
import { TheIcon } from 'the-icon'
import { get } from 'the-window'
import TheMicrophoneStyle from './TheMicrophoneStyle'

/**
 * Audio input of the-components
 */
class TheMicrophone extends React.Component {
  constructor (props) {
    super(props)
    this.recorder = null
    this.animationTimer = null
    this.state = {
      enlarged: false,
    }
  }

  componentDidMount () {
    this.animationTimer = setInterval(() => {
      this.setState({ enlarged: !this.state.enlarged })
    }, 800)
  }

  componentWillUnmount () {
    clearInterval(this.animationTimer)
  }

  render () {
    const { props, state } = this
    const {
      children,
      className,
      height,
      running,
      width,
    } = props
    const { enlarged } = state
    return (
      <div {...htmlAttributesFor(props, { except: ['className'] })}
           {...eventHandlersFor(props, { except: [] })}
           className={c('the-microphone', className, {
             'the-microphone-running': running,
           })}
      >
        <div className={c('the-microphone-back', {
          'the-microphone-back-enlarged': enlarged,
        })}/>
        <a className='the-microphone-icon'
           href='javascript:void(0)'
           onClick={this.handleClick}
           style={{ height, width }}
        >
          <TheIcon className={TheMicrophone.ICON}
                   style={{ fontSize: height * 0.66 }}
          />
          {children}
        </a>
      </div>
    )
  }
}

TheMicrophone.Style = TheMicrophoneStyle
TheMicrophone.ICON = 'fas fa-microphone'

TheMicrophone.propTypes = {
  /** Height of mic */
  height: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  /** Running or not */
  running: PropTypes.bool,
  /** Width of mic */
  width: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
}

TheMicrophone.defaultProps = {
  height: 92,
  running: false,
  width: 92,
}

TheMicrophone.displayName = 'TheMicrophone'

export default TheMicrophone
