'use strict'

import c from 'classnames'
import PropTypes from 'prop-types'
import React from 'react'
import { asStyleData } from 'the-component-util'
import { TheStyle } from 'the-style'

/** Style for TheMicrophone */
const TheMicrophoneStyle = ({ className, id, options }) => (
  <TheStyle {...{ id }}
            className={c('the-microphone-style', className)}
            styles={TheMicrophoneStyle.data(options)}
  />
)

TheMicrophoneStyle.displayName = 'TheMicrophoneStyle'
TheMicrophoneStyle.propTypes = {
  /** Style options */
  options: PropTypes.object,
}

TheMicrophoneStyle.defaultProps = {
  options: {},
}

TheMicrophoneStyle.data = (options) => {
  const { ThemeValues } = TheStyle
  const {
    dominantColor = ThemeValues.dominantColor,
  } = options
  return asStyleData({
    '.the-microphone': {
      alignItems: 'center',
      color: 'inherit',
      cursor: 'pointer',
      display: 'inline-flex',
      justifyContent: 'center',
      position: 'relative',
    },
    '.the-microphone-back': {
      '&.the-microphone-back-enlarged': {
        transform: 'scale(2, 2)',
      },
      backgroundColor: dominantColor,
      borderRadius: '50%',
      bottom: '9px',
      display: 'none',
      left: '9px',
      position: 'absolute',
      right: '9px',
      top: '9px',
      transform: 'scale(1, 1)',
      transformOrigin: '50% 50%',
      transition: `transform 800ms`,
    },
    '.the-microphone-icon': {
      '&:active': {
        opacity: 0.8,
      },
      alignItems: 'center',
      background: '#F0F0F0',
      border: '2px solid #DDD',
      borderRadius: '50%',
      boxSizing: 'border-box',
      color: '#CCC',
      cursor: 'pointer',
      display: 'flex',
      justifyContent: 'center',
      position: 'relative',
      textDecoration: 'none',
      zIndex: 4,
    },
    '.the-microphone-running': {
      '.the-microphone-back': {
        display: 'block',
      },
      '.the-microphone-icon': {
        background: 'transparent',
        borderColor: 'transparent',
        color: 'white',
        opacity: 0.9,
      },
    },
  })
}

export default TheMicrophoneStyle
